@@ -12,7 +12,7 @@ test_that('sequence with strong bias', {
     seq <- paste0(rep('AAA', 20), collapse = '')
     seqs <- Biostrings::DNAStringSet(seq)
     rscu <- est_rscu(count_codons(seqs))
-    expect_equal(rscu$rscu[rscu$codon == 'AAA'], 1 - 1/22)
+    expect_equal(rscu$prop[rscu$codon == 'AAA'], 1 - 1/22)
 })
 
 test_that('sequence with no bias', {
